summaryrefslogtreecommitdiffstats
path: root/src/katemdi.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/katemdi.h')
-rw-r--r--src/katemdi.h78
1 files changed, 42 insertions, 36 deletions
diff --git a/src/katemdi.h b/src/katemdi.h
index aca8419..177d3b2 100644
--- a/src/katemdi.h
+++ b/src/katemdi.h
@@ -25,40 +25,42 @@
#include <kmultitabbar.h>
-#include <qdict.h>
-#include <qintdict.h>
-#include <qsplitter.h>
+#include <tqdict.h>
+#include <tqintdict.h>
+#include <tqsplitter.h>
namespace KateMDI {
-/** This class is needed because QSplitter cant return an index for a widget. */
-class Splitter : public QSplitter
+/** This class is needed because TQSplitter cant return an index for a widget. */
+class Splitter : public TQSplitter
{
Q_OBJECT
+ TQ_OBJECT
public:
- Splitter(Orientation o, QWidget* parent=0, const char* name=0);
+ Splitter(Qt::Orientation o, TQWidget* tqparent=0, const char* name=0);
~Splitter();
/** Since there is supposed to be only 2 childs of a katesplitter,
* any child other than the last is the first.
* This method uses QSplitter::idAfter(widget) which
* returns 0 if there is no widget after this one.
* This results in an error if widget is not a child
* in this splitter */
- bool isLastChild(QWidget* w) const;
+ bool isLastChild(TQWidget* w) const;
- int idAfter ( QWidget * w ) const;
+ int idAfter ( TQWidget * w ) const;
};
class ToggleToolViewAction : public KToggleAction
{
Q_OBJECT
+ TQ_OBJECT
public:
- ToggleToolViewAction ( const QString& text, const KShortcut& cut,
- class ToolView *tv, QObject* parent = 0, const char* name = 0 );
+ ToggleToolViewAction ( const TQString& text, const KShortcut& cut,
+ class ToolView *tv, TQObject* tqparent = 0, const char* name = 0 );
virtual ~ToggleToolViewAction();
@@ -70,9 +72,10 @@ class ToggleToolViewAction : public KToggleAction
ToolView *m_tv;
};
-class GUIClient : public QObject, public KXMLGUIClient
+class GUIClient : public TQObject, public KXMLGUIClient
{
Q_OBJECT
+ TQ_OBJECT
public:
GUIClient ( class MainWindow *mw );
@@ -88,9 +91,10 @@ class GUIClient : public QObject, public KXMLGUIClient
MainWindow *m_mw;
};
-class ToolView : public QVBox
+class ToolView : public TQVBox
{
Q_OBJECT
+ TQ_OBJECT
friend class Sidebar;
friend class MainWindow;
@@ -105,9 +109,9 @@ class ToolView : public QVBox
* be automatically set to be the focus proxy of the toolview
* @param mainwin main window for this toolview
* @param sidebar sidebar of this toolview
* @param parent parent widget, e.g. the splitter of one of the sidebars
*/
- ToolView (class MainWindow *mainwin, class Sidebar *sidebar, QWidget *parent);
+ ToolView (class MainWindow *mainwin, class Sidebar *sidebar, TQWidget *tqparent);
public:
/**
@@ -137,7 +141,7 @@ class ToolView : public QVBox
bool visible () const;
protected:
- void childEvent ( QChildEvent *ev );
+ void childEvent ( TQChildEvent *ev );
private:
MainWindow *m_mainWin;
@@ -146,7 +150,7 @@ class ToolView : public QVBox
/**
* unique id
*/
- QString id;
+ TQString id;
/**
* is visible in sidebar
@@ -158,16 +162,17 @@ class ToolView : public QVBox
*/
bool persistent;
- QPixmap icon;
- QString text;
+ TQPixmap icon;
+ TQString text;
};
class Sidebar : public KMultiTabBar
{
Q_OBJECT
+ TQ_OBJECT
public:
- Sidebar (KMultiTabBar::KMultiTabBarPosition pos, class MainWindow *mainwin, QWidget *parent);
+ Sidebar (KMultiTabBar::KMultiTabBarPosition pos, class MainWindow *mainwin, TQWidget *tqparent);
virtual ~Sidebar ();
void setSplitter (Splitter *sp);
@@ -180,7 +185,7 @@ class Sidebar : public KMultiTabBar
KMultiTabBar::KMultiTabBarStyle sidebarTabStyle() const { return m_sidebarTabStyle; }
public:
- ToolView *addWidget (const QPixmap &icon, const QString &text, ToolView *widget);
+ ToolView *addWidget (const TQPixmap &icon, const TQString &text, ToolView *widget);
bool removeWidget (ToolView *widget);
bool showWidget (ToolView *widget);
@@ -210,7 +215,7 @@ class Sidebar : public KMultiTabBar
void tabClicked(int);
protected:
- bool eventFilter(QObject *obj, QEvent *ev);
+ bool eventFilter(TQObject *obj, TQEvent *ev);
private slots:
void buttonPopupActivate (int id);
@@ -224,13 +229,13 @@ class Sidebar : public KMultiTabBar
KMultiTabBar *m_tabBar;
Splitter *m_ownSplit;
- QIntDict<ToolView> m_idToWidget;
- QMap<ToolView*, int> m_widgetToId;
+ TQIntDict<ToolView> m_idToWidget;
+ TQMap<ToolView*, int> m_widgetToId;
/**
* list of all toolviews around in this sidebar
*/
- QValueList<ToolView*> m_toolviews;
+ TQValueList<ToolView*> m_toolviews;
int m_lastSize;
@@ -240,6 +245,7 @@ class Sidebar : public KMultiTabBar
class MainWindow : public KParts::MainWindow
{
Q_OBJECT
+ TQ_OBJECT
friend class ToolView;
@@ -250,7 +256,7 @@ class MainWindow : public KParts::MainWindow
/**
* Constructor
*/
- MainWindow (QWidget* parentWidget = 0, const char* name = 0);
+ MainWindow (TQWidget* tqparentWidget = 0, const char* name = 0);
/**
* Destructor
@@ -263,11 +269,11 @@ class MainWindow : public KParts::MainWindow
public:
/**
* central widget ;)
* use this as parent for your content
* this widget will get focus if a toolview is hidden
* @return central widget
*/
- QWidget *centralWidget () const;
+ TQWidget *centralWidget () const;
/**
* add a given widget to the given sidebar if possible, name is very important
@@ -277,14 +283,14 @@ class MainWindow : public KParts::MainWindow
* @param text text to use in addition to icon
* @return created toolview on success or 0
*/
- ToolView *createToolView (const QString &identifier, KMultiTabBar::KMultiTabBarPosition pos, const QPixmap &icon, const QString &text);
+ ToolView *createToolView (const TQString &identifier, KMultiTabBar::KMultiTabBarPosition pos, const TQPixmap &icon, const TQString &text);
/**
* give you handle to toolview for the given name, 0 if no toolview around
* @param identifier toolview name
* @return toolview if existing, else 0
*/
- ToolView *toolView (const QString &identifier) const;
+ ToolView *toolView (const TQString &identifier) const;
/**
* set the toolview's tabbar style.
@@ -341,7 +347,7 @@ class MainWindow : public KParts::MainWindow
* @param config config object to use
* @param group config group to use
*/
- void startRestore (KConfig *config, const QString &group);
+ void startRestore (KConfig *config, const TQString &group);
/**
* finish the restore
@@ -353,7 +359,7 @@ class MainWindow : public KParts::MainWindow
* @param config config object to use
* @param group config group to use
*/
- void saveSession (KConfig *config, const QString &group);
+ void saveSession (KConfig *config, const TQString &group);
/**
* internal data ;)
@@ -362,18 +368,18 @@ class MainWindow : public KParts::MainWindow
/**
* map identifiers to widgets
*/
- QDict<ToolView> m_idToWidget;
+ TQDict<ToolView> m_idToWidget;
/**
* list of all toolviews around
*/
- QValueList<ToolView*> m_toolviews;
+ TQValueList<ToolView*> m_toolviews;
/**
* widget, which is the central part of the
* main window ;)
*/
- QWidget *m_centralWidget;
+ TQWidget *m_centralWidget;
/**
* horizontal splitter
@@ -399,7 +405,7 @@ class MainWindow : public KParts::MainWindow
/**
* restore group
*/
- QString m_restoreGroup;
+ TQString m_restoreGroup;
/**
* out guiclient
@@ -25,40 +25,42 @@
/** Since there is supposed to be only 2 childs of a katesplitter,
* any child other than the last is the first.
- * This method uses QSplitter::idAfter(widget) which
+ * This method uses TQSplitter::idAfter(widget) which
* returns 0 if there is no widget after this one.
* This results in an error if widget is not a child
@@ -105,9 +109,9 @@ class ToolView : public QVBox
* @param mainwin main window for this toolview
* @param sidebar sidebar of this toolview
- * @param parent parent widget, e.g. the splitter of one of the sidebars
+ * @param tqparent tqparent widget, e.g. the splitter of one of the sidebars
*/
@@ -263,11 +269,11 @@ class MainWindow : public KParts::MainWindow
/**
* central widget ;)
- * use this as parent for your content
+ * use this as tqparent for your content
* this widget will get focus if a toolview is hidden
* @return central widget